@@ -23,9 +23,11 @@ def schedule(args):
         schedule_org = SAPOFTO.SAPOFTO('SCHEDULE',filename='session_schedule.org')
         if not  str(session_archetype) + ' SCHEDULE' in schedule_org.keys():
             schedule_org.addChild(SAPOFTO.SAPOFTO(str(session_archetype) + ' SCHEDULE'))
+        schedule_org = schedule_org[str(session_archetype) + ' SCHEDULE')]
     else:
         schedule_org = SAPOFTO.SAPOFTO('SCHEDULE')
-        schedule_org.addChild(SAPOFTO.SAPOFTO(str(session_archetype) + ' SCHEDULE'))        
+        schedule_org.addChild(SAPOFTO.SAPOFTO(str(session_archetype) + ' SCHEDULE'))
+        schedule_org = schedule_org[str(session_archetype) + ' SCHEDULE')]
     session_id = input('Please input the session\'s ID, or press enter to autogenerate a new ID...')
     if session_id == '':
         if os.path.isdir(os.path.join('sessions',session_archetype)):
@@ -33,22 +35,25 @@ def schedule(args):
         else:
             session_files = []            
             os.mkdir(os.path.join('sessions',session_archetype))
-        largest_id = 0        
-        for session_file in session_files:
-            if '.' in session_file:
-                continue
-            session_num = int(session_file)
-            if session_num > largest_id:
-                largest_id = session_num
-        new_id = largest_id + 1
-        preceding_zeroes = ''
-        if new_id < 1000:
-            preceding_zeroes += '0'
-        if new_id < 100:
-            preceding_zeroes += '0'
-        if new_id < 10:
-            preceding_zeroes += '0'
-        session_id = preceding_zeroes + str(new_id)
+        largest_id = 0
+        if len(session_files) == 0:
+            session_id = '0001'
+        else:
+            for session_file in session_files:
+                if '.' in session_file:
+                    continue
+                session_num = int(session_file)
+                if session_num > largest_id:
+                    largest_id = session_num
+            new_id = largest_id + 1
+            preceding_zeroes = ''
+            if new_id < 1000:
+                preceding_zeroes += '0'
+            if new_id < 100:
+                preceding_zeroes += '0'
+            if new_id < 10:
+                preceding_zeroes += '0'
+            session_id = preceding_zeroes + str(new_id)
     session_key = 'TODO ' + session_archetype + str(session_id)
     schedule_org.addChild(SAPOFTO.SAPOFTO(key=session_key))
     schedule_org[session_key].addChild(roles_node)
